@@ -9,19 +9,27 @@ class Widget:
             x=1
         if y == 0:
             y=1
-        if width == 0:
+        if width is None:
             width = 1
-        if height == 0:
+        if height is None:
             height = 1
-        self.px=1
+        if width <= 0:
+            width = 1
+        if height <= 0:
+            height = 1
+        if width >= 100:
+            width=99
+        if height >= 100:
+            height =99
+        self.px=x
         self.py=y
         if width == None:
             self.pw=width
         else:
-            self.pw=width
+            self.pw=width+x
             self.width = int(width * terminalSize[0] / 100)
         if height == None:
-            self.ph=height
+            self.ph=height+y
         else:
             self.ph=height
             self.height = int(height * terminalSize[1] / 100)
@@ -55,9 +63,23 @@ class Widget:
             self.height = int(self.ph * terminalSize[1] / 100)
         self.x = int(self.px * terminalSize[0] / 100)
         self.y = int(self.py * terminalSize[1] / 100)
+        self.render()
     
     def add_parent(self, parent):
         self.parent=parent
+        if parent == self.app:
+            pass
+        else:
+            #changing x and y proportionaly
+            self.x = parent.x + int(self.px * parent.width / 100)
+            self.y = parent.y + int(self.py * parent.height / 100)
+
+            # Relative size (%)
+            if self.pw is not None:
+                self.width = int(self.pw * parent.width / 100)
+            if self.ph is not None:
+                self.height = int(self.ph * parent.height / 100)
+
     def delete(self):
         self.parent.widgets.remove(self)
         self.app.stdscr.refresh()
\ No newline at end of file
