@@ -7,6 +7,7 @@ class Button(Widget):
         self.text = text
         self.on_press = on_press
 
+
     def render(self):
         theme = self.app.theme.get_button_theme()
         # start and end theme
@@ -31,3 +32,7 @@ class Button(Widget):
                 self.on_press()
             return True
         return False
+
+    
+    def delete(self):
+        self.parent.widgets.remove(self)
\ No newline at end of file
